@@ -85,7 +85,7 @@
 #' # make fake data
 #' set.seed(6543)
 #' 
-#' build_date <- function(x) as.character(seq(x, length.out=5, by="1 hour"))
+#' build_date <- function(x) format(seq(x, length.out=5, by="1 hour"), "%Y-%m-%d %H:%M")
 #' dates <- unlist(lapply(rep(Sys.time(),3), build_date))
 #'
 #' plconc <- data.frame(mod_id = rep(1:3,each=5),
@@ -430,7 +430,7 @@ run_Build_PK_IV <- function(conc, conc.columns = list(),
   }
 
   datetime <- as.POSIXct(tmp[,'date'])
-  tmp[,'date'] <- as.character(datetime, format = date.format, tz = date.tz)
+  tmp[,'date'] <- format(datetime, format = date.format, tz = date.tz)
 
   if(hasDemo) {
     if(!('idvisit' %in% names(demo.col))) {
